package org.rcisoft.bus.taskinfo.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.bus.taskinfo.dao.TaskInfoRepository;
import org.rcisoft.bus.taskinfo.entity.TaskInfo;
import org.rcisoft.bus.taskinfo.service.TaskInfoService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年5月15日 下午6:59:06.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TaskInfoServiceImpl extends ServiceImpl<TaskInfoRepository,TaskInfo>  implements TaskInfoService {


    /**
    * 保存 ?????
    * @param taskInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(TaskInfo taskInfo){
        //增加操作
        int line = baseMapper.insert(taskInfo);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            taskInfo.getBusinessId()+"的?????信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 ?????
    * @param taskInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TaskInfo taskInfo){
        int line = baseMapper.realDelete(taskInfo);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            taskInfo.getBusinessId()+"的?????信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 ?????
    * @param taskInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(TaskInfo taskInfo){
        taskInfo.setDeleted();
        int line = baseMapper.deleteById(taskInfo);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                taskInfo.getBusinessId()+"的?????信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 ?????
    * @param taskInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(TaskInfo taskInfo){
        int line = baseMapper.updateById(taskInfo);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ taskInfo.getBusinessId()+"的?????信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 ?????
    * @param id
    * @return
    */
    @Override
    public TaskInfo findById(String id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 ?????
    * @param taskInfo
    * @return
    */
    @Override
    public IPage<TaskInfo> findAllByPagination(CyPageInfo<TaskInfo> paginationUtility,
        TaskInfo taskInfo){
        return baseMapper.queryTaskInfosPaged(paginationUtility,taskInfo);

    }

    /**
    * 查询list ?????
    * @param taskInfo
    * @return
    */
    @Override
    public List<TaskInfo> findAll(TaskInfo taskInfo){
        return baseMapper.queryTaskInfos(taskInfo);

    }

    /**
    * 导出?????
    * @return
    */
    @Override
    public List<TaskInfo> export(TaskInfo taskInfo) {
        List<TaskInfo> taskInfoList = baseMapper.queryTaskInfos(taskInfo);
        return taskInfoList;
    }

}
